package com.hungraim.ism.gateway.config.tokenGranters;

import com.hungraim.ism.api.WechatFeignService;
import com.hungraim.ism.pojo.entity.system.SystemUser;
import com.hungraim.ism.pojo.vo.system.UserLoginInfoVO;
import com.hungraim.ism.util.Result;
import com.hungraim.ism.util.ResultCode;
import org.springframework.security.core.Authentication;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.oauth2.common.exceptions.InvalidGrantException;
import org.springframework.security.oauth2.provider.*;
import org.springframework.security.oauth2.provider.token.AbstractTokenGranter;
import org.springframework.security.oauth2.provider.token.AuthorizationServerTokenServices;

import java.util.LinkedHashMap;
import java.util.Map;

/**
 * 自定义grant_type模式--企业微信认证
 * @author hubin
 */
public class EnterpriseWechatTokenGranter extends AbstractTokenGranter {

  private static final String GRANT_TYPE = "enterpriseWechat";

 private final WechatFeignService wechatFeignService;

  public EnterpriseWechatTokenGranter(AuthorizationServerTokenServices tokenServices, ClientDetailsService clientDetailsService, OAuth2RequestFactory oAuth2RequestFactory, WechatFeignService wechatFeignService) {
    super(tokenServices,clientDetailsService,oAuth2RequestFactory,GRANT_TYPE);
      this.wechatFeignService = wechatFeignService;
  }


  @SuppressWarnings("AlibabaLowerCamelCaseVariableNaming")
  @Override
  protected OAuth2Authentication getOAuth2Authentication(ClientDetails client, TokenRequest tokenRequest) {
    Map<String, String> parameters = new LinkedHashMap<>(tokenRequest.getRequestParameters());
    String code = parameters.get("code");
    //通过code去企业微信获取用户id 再组装成用户
    Result<SystemUser> user = wechatFeignService.getUserInfoByCode(code);
    if(user==null || !ResultCode.SUCCESS.getCode().equals(user.getCode())){
      throw new InvalidGrantException(user.getMsg());
    }
    UserDetails userDTO = new UserLoginInfoVO(user.getData());
    Authentication userAuth = new UsernamePasswordAuthenticationToken(userDTO, null, userDTO.getAuthorities());
    return new OAuth2Authentication( getRequestFactory().createOAuth2Request(client, tokenRequest), userAuth);
  }


  }
