package com.hungraim.ism.system.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.hungraim.ism.pojo.entity.system.SystemAgency;
import com.hungraim.ism.pojo.entity.system.SystemCity;
import com.hungraim.ism.pojo.entity.system.SystemProvince;
import com.hungraim.ism.system.service.ISystemAgencyService;
import com.hungraim.ism.system.service.ISystemCityService;
import com.hungraim.ism.system.service.ISystemProvinceService;
import com.hungraim.ism.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 下拉框选项
 *
 * @author jiaguokai
 */
@RestController
@RequestMapping("/api.system/dropDown")
@Slf4j
public class DropDownController {
    @Autowired
    private ISystemProvinceService provinceService;
    @Autowired
    private ISystemCityService cityService;
    @Autowired
    private ISystemAgencyService agencyService;


    /**
     * 所有可用机构
     *
     * @return
     */
    @RequestMapping(value = "/loadAgency", method = RequestMethod.GET)
    public Result loadAgency() {
        List<SystemAgency> agencyList = agencyService.list(new LambdaQueryWrapper<SystemAgency>().eq(SystemAgency::getEnable, "1"));
        if (agencyList == null) {
            log.warn("DropDownController --- loadAgency --- 当前无可用机构");
            return Result.failed("当前无可用机构");
        }
        return Result.success(agencyList);
    }

    /**
     * 所有可用省份
     *
     * @return
     */
    @RequestMapping(value = "/loadProvince", method = RequestMethod.GET)
    public Result loadProvince() {
        List<SystemProvince> provinceList = provinceService.list(new LambdaQueryWrapper<SystemProvince>().eq(SystemProvince::getEnable, "1"));
        if (provinceList == null) {
            log.warn("DropDownController --- loadProvince --- 当前无可用省份");
            return Result.failed("当前无可用省份");
        }
        return Result.success(provinceList);
    }

    /**
     * 当前省份的可用城市
     *
     * @param province
     * @return
     */
    @GetMapping(value = "/loadCity/{province}")
    public Result loadCity(@PathVariable String province) {
        List<SystemCity> cityList = cityService.list(new LambdaQueryWrapper<SystemCity>().eq(SystemCity::getEnable, "1").eq(SystemCity::getProvinceCode, province));
        if (cityList == null) {
            log.warn("DropDownController --- loadCity --- 当前省份无可用城市");
            return Result.failed("当前省份无可用城市");
        }
        return Result.success(cityList);
    }
}
