package com.hungraim.ism.system.controller;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.hungraim.ism.pojo.entity.system.SystemMarketer;
import com.hungraim.ism.pojo.entity.system.SystemUser;
import com.hungraim.ism.pojo.entity.system.SystemUserRole;
import com.hungraim.ism.system.service.ISystemMarketerService;
import com.hungraim.ism.system.service.ISystemUserRoleService;
import com.hungraim.ism.system.service.ISystemUserService;
import com.hungraim.ism.system.service.impl.SystemUserRoleServiceImpl;
import com.hungraim.ism.system.service.impl.SystemUserServiceImpl;
import com.hungraim.ism.util.Result;
import com.hungraim.ism.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @author hubin
 */
@RestController
@RequestMapping("/api.system/user")
@Slf4j
public class UserController {


    private final ISystemUserService userInfoService;
    private final ISystemUserRoleService userRoleService;
    private final ISystemMarketerService marketerService;

    @Autowired
    public UserController(SystemUserServiceImpl userInfoService, SystemUserRoleServiceImpl userRoleService, ISystemMarketerService marketerService) {
        this.userInfoService = userInfoService;
        this.userRoleService = userRoleService;
        this.marketerService = marketerService;
    }


    /**
     * 根据用户账号获取用户基本信息
     *
     * @param account 用户账号
     * @return 营销员信息
     */
    @GetMapping("/loadUserInfoByAccount/{account}")
    public Result<SystemUser> loadUserInfoByAccount(@PathVariable String account) {
        log.info("user:{} 请求登陆。。。", account);
        SystemUser systemUser = userInfoService.getOne(new LambdaQueryWrapper<SystemUser>().eq(SystemUser::getAccount, account));
        if (systemUser == null) {
            log.warn("user:{} 账号未找到！", account);
            return Result.failed(ResultCode.USER_NOT_EXIST);
        }
        return Result.success(systemUser);
    }

    /**
     * 根据用户id获取用户权限
     *
     * @param id 用户id
     * @return 权限列表
     */
    @GetMapping("/loadUserRolesByUserId/{id}")
    public Result loadUserRolesByUserId(@PathVariable Long id) {
        List<Long> roleIds = userRoleService.list(new LambdaQueryWrapper<SystemUserRole>()
            .eq(SystemUserRole::getUserId, id)
        ).stream().map(SystemUserRole::getRoleId).collect(Collectors.toList());
        log.info("user:{},拥有的权限:{}", id, roleIds);
        return Result.success(roleIds);
    }

    /**
     * 根据用户表关联的marketerCode获取用户绑定的营销员信息
     *
     * @param code 营销员id
     * @return 权限列表
     */
    @GetMapping("/loadUserDetailByCode/{code}")
    public Result loadUserDetailByCode(@PathVariable String code) {
       SystemMarketer marketer = marketerService.getOne(new LambdaQueryWrapper<SystemMarketer>()
            .eq(SystemMarketer::getMarketerCode, code));
        if (marketer == null) {
            log.warn("code:{} 营销员信息未找到！", code);
            return Result.failed(ResultCode.MARKETER_NOT_EXIST);
        }
        return Result.success(marketer);
    }

}
